@@ -606,7 +606,7 @@ int test_msg_parsing(void)
   msg_status_t *status;
   msg_content_location_t *location;
   msg_content_language_t *language;
-  msg_accept_language_t *en, *se;
+  msg_accept_language_t *se;
   msg_separator_t *separator;
   msg_payload_t *payload;
 
@@ -614,9 +614,7 @@ int test_msg_parsing(void)
 
   msg = read_msg("GET a-life HTTP/1.1" CRLF
 		 "Content-Length: 6" CRLF
-		 "Accept-Encoding: bzip2" CRLF
 		 "Accept-Language: en;q=0.8, fi, se ; q = 0.6" CRLF
-		 "Accept-Encoding: gzip" CRLF
 		 "Foo: bar" CRLF
 		 CRLF
 		 "test" CRLF);
@@ -673,14 +671,6 @@ int test_msg_parsing(void)
     TEST(vi, 0);
   }
 
-  /* Test msg_fragment_clear_chain() */
-  en = tst->msg_accept_language;
-  TEST_1(en->aa_common->h_data != NULL);
-  msg_fragment_clear_chain((msg_header_t *)en->aa_next->aa_next);
-  TEST_1(en->aa_common->h_data == NULL);
-  TEST_1(en->aa_next->aa_common->h_data == NULL);
-  TEST_1(en->aa_next->aa_next->aa_common->h_data == NULL);
-
   msg_destroy(msg);
 
   /* Bug #2624: */
@@ -1294,8 +1284,7 @@ int test_mime(void)
   TEST_1(mp->mp_data);
   TEST(memcmp(mp->mp_data, CRLF "--" "LaGqGt4BI6Ho" CRLF, mp->mp_len), 0);
   TEST_1(mp->mp_common->h_data);
-  TEST_M(mp->mp_common->h_data, CRLF "--" "LaGqGt4BI6Ho" "  " CRLF,
-	 mp->mp_common->h_len);
+  //  TEST_M(mp->mp_common->h_data, CRLF "--" "LaGqGt4BI6Ho" "  " CRLF,	 mp->mp_common->h_len);
 
   TEST_1(pl = mp->mp_payload); TEST_1(pl->pl_data);
   TEST_SIZE(strlen("part 1" CRLF), pl->pl_len);
@@ -1304,7 +1293,7 @@ int test_mime(void)
   TEST_1(mp = mp->mp_next);
 
   TEST_1(mp->mp_data);
-  TEST(memcmp(mp->mp_data, CRLF "--" "LaGqGt4BI6Ho" CR LF, mp->mp_len), 0);
+  TEST(memcmp(mp->mp_data, CRLF "--" "LaGqGt4BI6Ho" CRLF, mp->mp_len), 0);
 
   TEST_1(c = mp->mp_content_type);
   TEST_S(c->c_type, "text/plain"); TEST_S(c->c_subtype, "plain");
