@@ -41,7 +41,11 @@
 
 #include "nea_debug.h"
 
+#ifndef _MSC_VER
 #define NONE ((void *)- 1)
+#else
+#define NONE ((void *)(INT_PTR)- 1)
+#endif
 
 #define SU_ROOT_MAGIC_T      struct nea_server_s
 #define SU_MSG_ARG_T         tagi_t
@@ -420,12 +424,12 @@ nea_server_t *nea_server_create(nta_agent_t *agent,
     throttle = min_throttle;
 
   if (!url) {
-    SU_DEBUG_5(("nea_server_create(): invalid url\n"));
+    SU_DEBUG_5(("nea_server_create(): invalid url\n" VA_NONE));
     return NULL;
   }
 
   if (min_expires > expires || expires > max_expires) {
-    SU_DEBUG_5(("nea_server_create(): invalid expiration range\n"));
+    SU_DEBUG_5(("nea_server_create(): invalid expiration range\n" VA_NONE));
     return NULL;
   }
 
@@ -546,7 +550,7 @@ int nea_server_shutdown(nea_server_t *nes,
 			int retry_after)
 {
   nea_sub_t *s;
-  int status = 200;
+//  int status = 200;
   int in_callback;
 
   if (nes == NULL)
@@ -572,8 +576,8 @@ int nea_server_shutdown(nea_server_t *nes,
 		   TAG_IF(!retry_after, NEATAG_REASON("deactivated")),
 		   TAG_IF(retry_after, NEATAG_RETRY_AFTER(retry_after)),
 		   TAG_END());
-    else
-      status = 180;
+    //else
+      //status = 180;
   }
 
   nes->nes_in_callback = in_callback;
@@ -840,7 +844,7 @@ int nea_view_update(nea_server_t *nes,
     nea_view_queue(nes, evv, evq);
 
   SU_DEBUG_7(("nea_server_update(%p): %s (%s)\n", (void *)nes,
-	      ev->ev_event->o_type, evv->evv_content_type->c_type));
+	      ev->ev_event->o_type, (evv->evv_content_type ? evv->evv_content_type->c_type : "N/A")));
 
   return 1;
 }
