@@ -56,7 +56,11 @@
 #include <sofia-sip/su_string.h>
 #include <sofia-sip/su_errno.h>
 
+#ifndef _MSC_VER
 #define NONE ((void *)-1)
+#else
+#define NONE ((void *)(INT_PTR)-1)
+#endif
 #define XXX assert(!"implemented")
 
 typedef unsigned longlong ull;
@@ -71,8 +75,6 @@ static char const __func__[] = "soa";
 /* ======================================================================== */
 
 /* Internal prototypes */
-su_inline int soa_media_is_ready(soa_session_t const *ss);
-
 enum soa_sdp_kind {
   soa_capability_sdp_kind,
   soa_user_sdp_kind,
@@ -389,9 +391,8 @@ void soa_base_deinit(soa_session_t *ss)
  * SOATAG_RTP_SORT(),
  * SOATAG_RTP_MISMATCH(),
  * SOATAG_SRTP_ENABLE(),
- * SOATAG_SRTP_CONFIDENTIALITY(),
- * SOATAG_SRTP_INTEGRITY(), and
- * SOATAG_DELAYED_OFFER_ENABLE().
+ * SOATAG_SRTP_CONFIDENTIALITY(), and
+ * SOATAG_SRTP_INTEGRITY().
  */
 int soa_set_params(soa_session_t *ss, tag_type_t tag, tag_value_t value, ...)
 {
@@ -435,9 +436,8 @@ int soa_set_params(soa_session_t *ss, tag_type_t tag, tag_value_t value, ...)
  * SOATAG_RTP_SORT(),
  * SOATAG_RTP_MISMATCH(),
  * SOATAG_SRTP_ENABLE(),
- * SOATAG_SRTP_CONFIDENTIALITY(),
- * SOATAG_SRTP_INTEGRITY(), and
- * SOATAG_DELAYED_OFFER_ENABLE().
+ * SOATAG_SRTP_CONFIDENTIALITY(), and
+ * SOATAG_SRTP_INTEGRITY().
  */
 int soa_base_set_params(soa_session_t *ss, tagi_t const *tags)
 {
@@ -451,7 +451,6 @@ int soa_base_set_params(soa_session_t *ss, tagi_t const *tags)
   int rtp_select, rtp_sort;
   int rtp_mismatch;
   int srtp_enable, srtp_confidentiality, srtp_integrity;
-  int delayed_offer_enable;
 
   af = ss->ss_af;
 
@@ -466,8 +465,6 @@ int soa_base_set_params(soa_session_t *ss, tagi_t const *tags)
   srtp_confidentiality = ss->ss_srtp_confidentiality;
   srtp_integrity = ss->ss_srtp_integrity;
 
-  delayed_offer_enable = ss->ss_delayed_offer_enable;
-
   caps_sdp = user_sdp = NONE;
   caps_sdp_str = user_sdp_str = NONE;
 
@@ -491,8 +488,6 @@ int soa_base_set_params(soa_session_t *ss, tagi_t const *tags)
 	      SOATAG_SRTP_CONFIDENTIALITY_REF(srtp_confidentiality),
 	      SOATAG_SRTP_INTEGRITY_REF(srtp_integrity),
 
-	      SOATAG_DELAYED_OFFER_ENABLE_REF(delayed_offer_enable),
-
 	      TAG_END());
 
   if (n <= 0)
@@ -541,8 +536,6 @@ int soa_base_set_params(soa_session_t *ss, tagi_t const *tags)
   srtp_confidentiality = srtp_confidentiality != 0;
   srtp_integrity = srtp_integrity != 0;
 
-  delayed_offer_enable = delayed_offer_enable != 0;
-
   change_session
     =  af != (int)ss->ss_af
     || rtp_select != (int)ss->ss_rtp_select
@@ -551,7 +544,6 @@ int soa_base_set_params(soa_session_t *ss, tagi_t const *tags)
     || srtp_enable != (int)ss->ss_srtp_enable
     || srtp_confidentiality != (int)ss->ss_srtp_confidentiality
     || srtp_integrity != (int)ss->ss_srtp_integrity
-    || delayed_offer_enable != (int)ss->ss_delayed_offer_enable
     ;
 
   ss->ss_af = (enum soa_af)af;
@@ -564,11 +556,10 @@ int soa_base_set_params(soa_session_t *ss, tagi_t const *tags)
   ss->ss_srtp_confidentiality = srtp_confidentiality;
   ss->ss_srtp_integrity = srtp_integrity;
 
-  ss->ss_delayed_offer_enable = delayed_offer_enable;
-
   if (!su_casematch(media_address, ss->ss_address)) {
-    su_free(ss->ss_home, (void *)ss->ss_address);
+    char const *addr = ss->ss_address;
     ss->ss_address = su_strdup(ss->ss_home, media_address);
+    su_free(ss->ss_home, (void *)addr);
     change_session = 1;
   }
 
@@ -576,8 +567,9 @@ int soa_base_set_params(soa_session_t *ss, tagi_t const *tags)
     hold = "*";
 
   if (!su_casematch(hold, ss->ss_hold)) {
-    su_free(ss->ss_home, (void *)ss->ss_hold);
+    char const *h = ss->ss_hold;
     ss->ss_hold = su_strdup(ss->ss_home, hold);
+    su_free(ss->ss_home, (void *)h);
     change_session = 1;
   }
 
@@ -659,9 +651,8 @@ int soa_get_params(soa_session_t const *ss,
  * SOATAG_RTP_SORT(),
  * SOATAG_RTP_MISMATCH(),
  * SOATAG_SRTP_ENABLE(),
- * SOATAG_SRTP_CONFIDENTIALITY(),
- * SOATAG_SRTP_INTEGRITY(), and
- * SOATAG_DELAYED_OFFER_ENABLE().
+ * SOATAG_SRTP_CONFIDENTIALITY(), and
+ * SOATAG_SRTP_INTEGRITY().
  */
 int soa_base_get_params(soa_session_t const *ss, tagi_t *tags)
 {
@@ -692,8 +683,6 @@ int soa_base_get_params(soa_session_t const *ss, tagi_t *tags)
 	       SOATAG_SRTP_CONFIDENTIALITY(ss->ss_srtp_confidentiality),
 	       SOATAG_SRTP_INTEGRITY(ss->ss_srtp_integrity),
 
-	       SOATAG_DELAYED_OFFER_ENABLE(ss->ss_delayed_offer_enable),
-
 	       TAG_END());
 
   return n;
@@ -1889,12 +1878,6 @@ int soa_is_remote_chat_active(soa_session_t const *ss)
   return ma;
 }
 
-/** Return true if delayed offer has been activated. */
-int soa_is_delayed_offer(soa_session_t const *ss)
-{
-  return ss ? ss->ss_delayed_offer_enable : 0;
-}
-
 /* ======================================================================== */
 /* Methods used by soa instances */
 
@@ -1914,14 +1897,6 @@ int soa_set_warning(soa_session_t *ss, int code, char const *text)
   return -1;
 }
 
-su_inline
-int soa_media_is_ready(soa_session_t const *ss)
-{
-  XXX;
-  return 0;
-  /* return ss && ss->ss_session != NULL; */
-}
-
 void soa_set_activity(soa_session_t *ss,
 		      sdp_media_t const *m,
 		      enum soa_activity activity)
@@ -2664,7 +2639,7 @@ best_listed_address_in_session(sdp_session_t const *sdp,
       for (m = sdp->sdp_media; m; m = m->m_next) {
 	if (m->m_connections && m->m_connections != sdp->sdp_connection) {
 	  c = sdp->sdp_connection;
-	  if (su_casenmatch(c->c_address, address, n) && c->c_address[n] == 0)
+	  if (c && su_casenmatch(c->c_address, address, n) && c->c_address[n] == 0)
 	    break;
 	  c = NULL;
 	}
